.. _refman_ext_client:

Client
======

This section contains source code documentation of Client extension.
   
core
^^^^   
   
.. _refman_ext_client_core_autocompleter:

* autocompleter

.. automodule:: hydratk.extensions.client.core.autocompleter
   :member-order: bysource   
   
.. _refman_ext_client_core_colorizer:   
   
* colorizer

.. automodule:: hydratk.extensions.client.core.colorizer
   :member-order: bysource      
   
.. _refman_ext_client_core_config:   
   
* config

.. automodule:: hydratk.extensions.client.core.config
   :member-order: bysource   
   
.. _refman_ext_client_core_editor:   
   
* editor

.. automodule:: hydratk.extensions.client.core.editor
   :member-order: bysource   
   
.. _refman_ext_client_core_explorer:   
   
* explorer

.. automodule:: hydratk.extensions.client.core.explorer
   :member-order: bysource   
   
.. _refman_ext_client_core_filetab:   
   
* filetab

.. automodule:: hydratk.extensions.client.core.filetab
   :member-order: bysource   
   
.. _refman_ext_client_core_formatter:   
   
* formatter

.. automodule:: hydratk.extensions.client.core.formatter
   :member-order: bysource   
   
.. _refman_ext_client_core_gui:   
   
* gui

.. automodule:: hydratk.extensions.client.core.gui
   :member-order: bysource   
   
.. _refman_ext_client_core_help:   
   
* help

.. automodule:: hydratk.extensions.client.core.help
   :member-order: bysource   
   
.. _refman_ext_client_core_logger:   
   
* logger

.. automodule:: hydratk.extensions.client.core.logger
   :member-order: bysource   
   
.. _refman_ext_client_core_notebook:   
   
* notebook

.. automodule:: hydratk.extensions.client.core.notebook
   :member-order: bysource     
   
.. _refman_ext_client_core_plugin:   
   
* plugin

.. automodule:: hydratk.extensions.client.core.plugin
   :member-order: bysource   
   
.. _refman_ext_client_core_pluginmanager:   
   
* pluginmanager

.. automodule:: hydratk.extensions.client.core.pluginmanager
   :member-order: bysource        
   
.. _refman_ext_client_core_tooltip:   
   
* tooltip

.. automodule:: hydratk.extensions.client.core.tooltip
   :member-order: bysource    
   
.. _refman_ext_client_core_translator:   
   
* translator

.. automodule:: hydratk.extensions.client.core.translator
   :member-order: bysource    
   
.. _refman_ext_client_core_utils:   
   
* utils

.. automodule:: hydratk.extensions.client.core.utils
   :member-order: bysource    
   
.. _refman_ext_client_core_yoda_tree:   
   
* yoda_tree

.. automodule:: hydratk.extensions.client.core.yoda_tree
   :member-order: bysource       
   
plugins
^^^^^^^

.. _refman_ext_client_plugins_syntaxchecker:   
   
* syntaxchecker

.. automodule:: hydratk.extensions.client.plugins.syntaxchecker.syntaxchecker
   :member-order: bysource
   
.. _refman_ext_client_plugins_gitclient:   
   
* gitclient

.. automodule:: hydratk.extensions.client.plugins.gitclient.gitclient
   :member-order: bysource                                                   